#!/usr/bin/env python
# coding: utf-8

# In[ ]:


import math
from scipy.stats import rankdata
import numpy as np

def topsi(df,impact,c):
    data=df.iloc[:,1:].values
    data_norm=data/(np.sqrt(np.power(data,2).sum(axis=0)))
    data_norm_w=data_norm*c
    
    positive =[]
    negative = []
        

    
    for i in range(0, len(data_norm_w[0])):
        min = 100000000
        max = -100000000
        for j in range(0,len(data_norm_w)):
            if min > data_norm_w[j][i]:
                min= data_norm_w[j][i]
            if max < data_norm_w[j][i]:
                max = data_norm_w[j][i]
        if impact[i] == '+':
            positive.append(max)
            negative.append(min)
        if impact[i] == '-':
            positive.append(min)
            negative.append(max)
            
    sm_p=np.sqrt(np.power(data_norm_w-positive,2).sum(axis=1))
    sm_n=np.sqrt(np.power(data_norm_w-negative,2).sum(axis=1))
    performance=sm_n/(sm_n+sm_p)
    
    rank = len(performance) - rankdata(performance, method = 'min').astype(int) + 1
 
    rank = rank.tolist()
    df["Topsis Score"] = performance
    df["Rank"] = rank
    return df



from setuptools import setup

with open("README.md","r") as fh:
    long_description = fh.read()

setup(
  name = 'TOPSIS-Ria-101803043',
  version = '0.0.1',
  description = 'Find the Topsis Score ',
  py_modules = ["topsis"],
  package_dir = {'':'TOPSIS-Ria-101803043'},
  package_data={'':['LICENSE.txt']},
  include_package_data=True,
  author="Ria Kapoor",
  author_email="kkapoorria581@gmail.com",
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
  long_description=long_description,
  long_description_content_type="text/markdown",
  extras_require={
    "dev":[
        "pytest>=3.7",
    ],
  },
)
